using System;
using System.Collections.Generic;
using System.IO;
using UnityEngine;
using UnityEngine.Events;

namespace Mod
{
    public class Mod
    {
        public static void Main()
        {
// register item to the mod registry
ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Android"), //item to derive from
        NameOverride = "Slashers", //new item name with a suffix to assure it is globally unique
        DescriptionOverride = "Slashers are the most common form of Necromorphs. While relatively weak when alone, and possessing slow reflexes, Slashers can pose a serious threat when in groups.", //new item description
        CategoryOverride = ModAPI.FindCategory("Entities"), //new item category
        ThumbnailOverride = ModAPI.LoadSprite("slasherthumbnail.png"), //new item thumbnail (relative path)
        AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
        {
            //load textures for each layer (see Human textures folder in this repository)
            var skin = ModAPI.LoadTexture("slasher.png");
            var flesh = ModAPI.LoadTexture("eww flesh nasty.png");
            var bone = ModAPI.LoadTexture("i forgor.png");

            //get person
            var person = Instance.GetComponent<PersonBehaviour>();

            //use the helper function to set each texture
            //parameters are as follows: 
            //  skin texture, flesh texture, bone texture, sprite scale
            //you can pass "null" to fall back to the original texture
            person.SetBodyTextures(skin, flesh, bone, 1);

            //change procedural damage colours if they interfere with your texture (rgb 0-255)
            person.SetBruiseColor(86, 62, 130); //main bruise colour. purple-ish by default
            person.SetSecondBruiseColor(154, 0, 7); //second bruise colour. red by default
            person.SetThirdBruiseColor(207, 206, 120); // third bruise colour. light yellow by default
            person.SetRottenColour(202, 199, 104); // rotten/zombie colour. light yellow/green by default
            person.SetBloodColour(108, 0, 4); // blood colour. dark red by default. note that this does not change decal nor particle effect colours. it only affects the procedural blood color which may or may not be rendered
        }
    }
);
// register item to the mod registry
ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Android"), //item to derive from
        NameOverride = "Stalkers", //new item name with a suffix to assure it is globally unique
        DescriptionOverride = "The Stalker is a Necromorph that attacks its prey by means of flanking and group tactics. They approach slowly and quietly in order not to be discovered whilst they get closer, making them harder to notice. They are first encountered in Chapter 4 of Dead Space 2.", //new item description
        CategoryOverride = ModAPI.FindCategory("Entities"), //new item category
        ThumbnailOverride = ModAPI.LoadSprite("stalkerthumbnail.png"), //new item thumbnail (relative path)
        AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
        {
            //load textures for each layer (see Human textures folder in this repository)
            var skin = ModAPI.LoadTexture("stalker.png");
            var flesh = ModAPI.LoadTexture("eww flesh nasty.png");
            var bone = ModAPI.LoadTexture("i forgor.png");

            //get person
            var person = Instance.GetComponent<PersonBehaviour>();

            //use the helper function to set each texture
            //parameters are as follows: 
            //  skin texture, flesh texture, bone texture, sprite scale
            //you can pass "null" to fall back to the original texture
            person.SetBodyTextures(skin, flesh, bone, 1);

            //change procedural damage colours if they interfere with your texture (rgb 0-255)
            person.SetBruiseColor(86, 62, 130); //main bruise colour. purple-ish by default
            person.SetSecondBruiseColor(154, 0, 7); //second bruise colour. red by default
            person.SetThirdBruiseColor(207, 206, 120); // third bruise colour. light yellow by default
            person.SetRottenColour(202, 199, 104); // rotten/zombie colour. light yellow/green by default
            person.SetBloodColour(108, 0, 4); // blood colour. dark red by default. note that this does not change decal nor particle effect colours. it only affects the procedural blood color which may or may not be rendered
        }
    }
);
// register item to the mod registry
ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Human"), //item to derive from
        NameOverride = "Feeders", //new item name with a suffix to assure it is globally unique
        DescriptionOverride = "The Feeder is a Necromorph encountered on Tau Volantis. They are formed from humans that ingest Necromorph-infected meat.", //new item description
        CategoryOverride = ModAPI.FindCategory("Entities"), //new item category
        ThumbnailOverride = ModAPI.LoadSprite("feederthumbnail.png"), //new item thumbnail (relative path)
        AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
        {
            //load textures for each layer (see Human textures folder in this repository)
            var skin = ModAPI.LoadTexture("feeder.png");
            var flesh = ModAPI.LoadTexture("eww flesh nasty.png");
            var bone = ModAPI.LoadTexture("i forgor.png");

            //get person
            var person = Instance.GetComponent<PersonBehaviour>();

            //use the helper function to set each texture
            //parameters are as follows: 
            //  skin texture, flesh texture, bone texture, sprite scale
            //you can pass "null" to fall back to the original texture
            person.SetBodyTextures(skin, flesh, bone, 1);

            //change procedural damage colours if they interfere with your texture (rgb 0-255)
            person.SetBruiseColor(86, 62, 130); //main bruise colour. purple-ish by default
            person.SetSecondBruiseColor(154, 0, 7); //second bruise colour. red by default
            person.SetThirdBruiseColor(207, 206, 120); // third bruise colour. light yellow by default
            person.SetRottenColour(202, 199, 104); // rotten/zombie colour. light yellow/green by default
            person.SetBloodColour(108, 0, 4); // blood colour. dark red by default. note that this does not change decal nor particle effect colours. it only affects the procedural blood color which may or may not be rendered
        }
    }
);
// register item to the mod registry
ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Gorse"), //item to derive from
        NameOverride = "Infector", //new item name with a suffix to assure it is globally unique
        DescriptionOverride = "The Infector is a unique Necromorph. The Infector's sole purpose is to spread the Necromorph contagion, thus creating more Necromorphs to spread the infestation.", //new item description
        CategoryOverride = ModAPI.FindCategory("Entities"), //new item category
        ThumbnailOverride = ModAPI.LoadSprite("infectorthumbnail.png"), //new item thumbnail (relative path)
        AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
        {
            //load textures for each layer (see Human textures folder in this repository)
            var skin = ModAPI.LoadTexture("infector.png");
            var flesh = ModAPI.LoadTexture("infector flesh.png");
            var bone = ModAPI.LoadTexture("infector bone.png");

            //get person
            var person = Instance.GetComponent<PersonBehaviour>();

            //use the helper function to set each texture
            //parameters are as follows: 
            //  skin texture, flesh texture, bone texture, sprite scale
            //you can pass "null" to fall back to the original texture
            person.SetBodyTextures(skin, flesh, bone, 1);

            //change procedural damage colours if they interfere with your texture (rgb 0-255)
            person.SetBruiseColor(86, 62, 130); //main bruise colour. purple-ish by default
            person.SetSecondBruiseColor(154, 0, 7); //second bruise colour. red by default
            person.SetThirdBruiseColor(207, 206, 120); // third bruise colour. light yellow by default
            person.SetRottenColour(202, 199, 104); // rotten/zombie colour. light yellow/green by default
            person.SetBloodColour(108, 0, 4); // blood colour. dark red by default. note that this does not change decal nor particle effect colours. it only affects the procedural blood color which may or may not be rendered
        }
    }
);
// register item to the mod registry
ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Human"), //item to derive from
        NameOverride = "Pukers", //new item name with a suffix to assure it is globally unique
        DescriptionOverride = "The Puker is a unique ranged Necromorph encountered throughout the events of Dead Space 2 and later in Dead Space 3 as well.", //new item description
        CategoryOverride = ModAPI.FindCategory("Entities"), //new item category
        ThumbnailOverride = ModAPI.LoadSprite("pukerthumbnail.png"), //new item thumbnail (relative path)
        AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
        {
            //load textures for each layer (see Human textures folder in this repository)
            var skin = ModAPI.LoadTexture("puker.png");
            var flesh = ModAPI.LoadTexture("eww flesh nasty.png");
            var bone = ModAPI.LoadTexture("i forgor.png");
           
            //get person
            var person = Instance.GetComponent<PersonBehaviour>();

            //use the helper function to set each texture
            //parameters are as follows: 
            //  skin texture, flesh texture, bone texture, sprite scale
            //you can pass "null" to fall back to the original texture
            person.SetBodyTextures(skin, flesh, bone, 1);

            //change procedural damage colours if they interfere with your texture (rgb 0-255)
            person.SetBruiseColor(86, 62, 130); //main bruise colour. purple-ish by default
            person.SetSecondBruiseColor(154, 0, 7); //second bruise colour. red by default
            person.SetThirdBruiseColor(207, 206, 120); // third bruise colour. light yellow by default
            person.SetRottenColour(202, 199, 104); // rotten/zombie colour. light yellow/green by default
            person.SetBloodColour(108, 0, 4); // blood colour. dark red by default. note that this does not change decal nor particle effect colours. it only affects the procedural blood color which may or may not be rendered
        }
    }
);
// register item to the mod api
ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Stunner"), //item to derive from
        NameOverride = "Lurker", //new item name with a suffix to assure it is globally unique
        DescriptionOverride = "The Lurker is a Necromorph specialized for ranged attacks. NOTE: This one isn't a living NPC like the others, so if you want it to attack, press F to activate ranged weapon.", //new item description
        CategoryOverride = ModAPI.FindCategory("Entities"), //new item category
        ThumbnailOverride = ModAPI.LoadSprite("lurkerthumbnail.png"), //new item thumbnail (relative path)
        AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
        {
            //get the SpriteRenderer and replace its sprite with a custom one
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("lurker.png"); 
        }
    }
);
// register item to the mod api
ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Knife"), //item to derive from
        NameOverride = "Leaper", //new item name with a suffix to assure it is globally unique
        DescriptionOverride = "Leapers are Necromorphs appearing in almost all the Dead Space series, with the ability to leap long distances toward their prey.", //new item description
        CategoryOverride = ModAPI.FindCategory("Entities"), //new item category
        ThumbnailOverride = ModAPI.LoadSprite("leaperthumbnail.png"), //new item thumbnail (relative path)
        AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
        {
            //get the SpriteRenderer and replace its sprite with a custom one
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("leaper.png"); 
        }
    }
);
// register item to the mod api
ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Knife"), //item to derive from
        NameOverride = "Infector V2", //new item name with a suffix to assure it is globally unique
        DescriptionOverride = "An improved version of the Infector, so it looks more accurate and not just a re-skinned Gorse.", //new item description
        CategoryOverride = ModAPI.FindCategory("Entities"), //new item category
        ThumbnailOverride = ModAPI.LoadSprite("infector2thumbnail.png"), //new item thumbnail (relative path)
        AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
        {
            //get the SpriteRenderer and replace its sprite with a custom one
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("infector2.png"); 
        }
    }
);
// register item to the mod api
ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Plastic Explosive"), //item to derive from
        NameOverride = "Crawler", //new item name with a suffix to assure it is globally unique
        DescriptionOverride = "Crawlers are Necromorphs formed from human and alien infants. They are first introduced in Dead Space 2.", //new item description
        CategoryOverride = ModAPI.FindCategory("Entities"), //new item category
        ThumbnailOverride = ModAPI.LoadSprite("crawlerthumbnail.png"), //new item thumbnail (relative path)
        AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
        {
            //get the SpriteRenderer and replace its sprite with a custom one
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("crawler.png"); 
        }
    }
);
// register item to the mod registry
ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Human"), //item to derive from
        NameOverride = "Isaac Clarke", //new item name with a suffix to assure it is globally unique
        DescriptionOverride = "Isaac Clarke was a former ship systems engineer who worked for the Concordance Extraction Corporation, and the playable protagonist of the Dead Space series.", //new item description
        CategoryOverride = ModAPI.FindCategory("Entities"), //new item category
        ThumbnailOverride = ModAPI.LoadSprite("isaacthumbnail.png"), //new item thumbnail (relative path)
        AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
        {
            //load textures for each layer (see Human textures folder in this repository)
            var skin = ModAPI.LoadTexture("isaac.png");
            var flesh = ModAPI.LoadTexture("isaac flesh.png");
            var bone = ModAPI.LoadTexture("isaac skeleton.png");

            //get person
            var person = Instance.GetComponent<PersonBehaviour>();

            //use the helper function to set each texture
            //parameters are as follows: 
            //  skin texture, flesh texture, bone texture, sprite scale
            //you can pass "null" to fall back to the original texture
            person.SetBodyTextures(skin, flesh, bone, 1);

            //change procedural damage colours if they interfere with your texture (rgb 0-255)
            person.SetBruiseColor(86, 62, 130); //main bruise colour. purple-ish by default
            person.SetSecondBruiseColor(154, 0, 7); //second bruise colour. red by default
            person.SetThirdBruiseColor(207, 206, 120); // third bruise colour. light yellow by default
            person.SetRottenColour(202, 199, 104); // rotten/zombie colour. light yellow/green by default
            person.SetBloodColour(108, 0, 4); // blood colour. dark red by default. note that this does not change decal nor particle effect colours. it only affects the procedural blood color which may or may not be rendered
        }
    }
);
        }
    }
}